@@ -284,10 +284,6 @@ class UI(builder.Builder):
         self.p_frame_annot.set_visible(self.show_annotations)
         self.laser.activate_pointermode()
 
-
-    def activate(self):
-        """ Activate application, i.e. bring windows to front.
-        """
         # Setup screens and show all windows
         self.setup_screens()
         self.c_win.show_all()
@@ -606,33 +602,34 @@ class UI(builder.Builder):
     ############################ Document manangement ############################
     ##############################################################################
 
-    def swap_document(self, docpath, page=0, reloading=False):
+    def swap_document(self, doc_uri, page=0, reloading=False):
         """ Replace the currently open document with a new one.
 
-        The new document is possibly and EmptyDocument if docpath is None.
+        The new document is possibly and EmptyDocument if doc_uri is None.
         The state of the ui and cache are updated accordingly.
 
         Args:
-            docpath (`str`): the absolute path to the new document
+            doc_uri (`str`): the URI to the new document
             page (`int`): the page at which to start the presentation
             reloading (`bool`): whether we are reloading or detecting stuff from the document
         """
         run_gc = self.doc.doc is not None
         try:
-            self.doc = document.Document.create(self, docpath)
+            self.doc = document.Document.create(self, doc_uri)
 
-            if not reloading and docpath:
-                Gtk.RecentManager.get_default().add_item(self.doc.get_uri())
+            if not reloading and doc_uri:
+                Gtk.RecentManager.get_default().add_item(doc_uri)
+                self.file_watcher.watch_file(doc_uri, self.reload_document)
 
-            if not reloading:
-                self.file_watcher.watch_file(self.doc.get_path(), self.reload_document)
+            elif not reloading:
+                self.file_watcher.stop_watching()
 
         except GLib.Error:
             if reloading:
                 return
 
             self.doc = document.Document.create(self, None)
-            self.error_opening_file(docpath)
+            self.error_opening_file(doc_uri)
             self.file_watcher.stop_watching()
 
         self.current_page = self.preview_page = self.doc.goto(page)
@@ -650,6 +647,8 @@ class UI(builder.Builder):
             # don't toggle from NONE to NONE
             if target_mode:
                 self.app.activate_action('notes-pos', target_mode.name.lower())
+        else:
+            self.doc.set_notes_after(self.notes_mode.direction() == 'page number')
 
         # Some things that need updating
         self.cache.swap_document(self.doc)
@@ -675,7 +674,7 @@ class UI(builder.Builder):
     def reload_document(self):
         """ Reload the current document.
         """
-        self.swap_document(self.doc.path, page=self.current_page, reloading=True)
+        self.swap_document(self.doc.get_uri(), page=self.current_page, reloading=True)
 
 
     def populate_recent_menu(self, gaction, is_opening=None):
@@ -749,7 +748,7 @@ class UI(builder.Builder):
         response = dialog.run()
 
         if response == Gtk.ResponseType.OK:
-            self.swap_document(os.path.abspath(dialog.get_filename()))
+            self.swap_document(dialog.get_uri())
 
         dialog.destroy()
 
@@ -778,6 +777,10 @@ class UI(builder.Builder):
 
     def open_file(self, gaction, target):
         """ Open a document.
+
+        Returns:
+            gaction (:class:`~Gio.Action`): the action triggering the call
+            target (:class:`~GLib.Variant`): the file to open as a string variant
         """
         self.swap_document(target.get_string())
 
@@ -1421,9 +1424,12 @@ class UI(builder.Builder):
     def switch_blanked(self, gaction, param):
         """ Switch the blanked mode of the content screen.
 
-        Returns:
+        Args:
             gaction (:class:`~Gio.Action`): the action triggering the call
             param (:class:`~GLib.Variant`): the parameter as a variant, or None
+
+        Returns:
+            `bool`: whether the notes blanking has been toggled.
         """
         self.blanked = not self.blanked
         self.c_da.queue_draw()
@@ -1434,6 +1440,12 @@ class UI(builder.Builder):
 
     def layout_name(self, notes_mode):
         """ Return the layout made for the selected notes_mode
+
+        Args:
+            notes_mode (:class:`~pympress.document.PdfPage`): the mode/positioning of notes
+
+        Returns:
+            `str`: a string representing the appropriate layout
         """
         if notes_mode.direction() == 'page number':
             return 'note_pages'
@@ -1465,7 +1477,12 @@ class UI(builder.Builder):
         """ Switch the position of the nodes in the slide.
 
         Returns:
-            `bool`: whether the mode has been toggled.
+            gaction (:class:`~Gio.Action`): the action triggering the call
+            target (:class:`~GLib.Variant`): the notes position as a string variant
+            force (`bool`): Whether to force the notes switch even if it’s already enabled
+
+        Returns:
+            `bool`: whether the notes position has been toggled
         """
         target_mode = document.PdfPage[target.get_string().upper()]
 
@@ -1490,7 +1507,12 @@ class UI(builder.Builder):
         """ Switch the display mode to "Notes mode" or "Normal mode" (without notes).
 
         Returns:
-            `bool`: whether the mode has been toggled.
+            gaction (:class:`~Gio.Action`): the action triggering the call
+            target_mode (:class:`~pympress.document.PdfPage`): the mode to which we should switch
+            force (`bool`): Whether to force the mode switch even if it’s already enabled
+
+        Returns:
+            `bool`: whether the notes mode has been toggled
         """
         if target_mode is None:
             target_mode = document.PdfPage.NONE if self.notes_mode else self.chosen_notes_mode
@@ -1532,6 +1554,10 @@ class UI(builder.Builder):
     def switch_annotations(self, gaction, target):
         """ Switch the display to show annotations or to hide them.
 
+        Returns:
+            gaction (:class:`~Gio.Action`): the action triggering the call
+            target (:class:`~GLib.Variant`): the parameter as a variant, or None
+
         Returns:
             `bool`: whether the mode has been toggled.
         """
